@@ -1,13 +1,26 @@
 import sys
-sys.path.append("..") # Adds the module to path
+
+sys.path.append("..")  # Adds the module to path
 
 import unittest
 
 import deeptrack.models as models
-
+import numpy as np
 
 
 class TestModels(unittest.TestCase):
+    def test_FullyConnected(self):
+        model = models.FullyConnected(
+            input_shape=(64, 2),
+            dense_layers_dimensions=(32, 32),
+            number_of_outputs=3,
+            output_activation="sigmoid",
+            loss="mse",
+            flatten_input=True,
+        )
+        self.assertIsInstance(model, models.KerasModel)
+
+        model.predict(np.zeros((1, 64, 2)))
 
     def test_Convolutions(self):
         model = models.Convolutional(
@@ -16,10 +29,11 @@ class TestModels(unittest.TestCase):
             dense_layers_dimensions=(32, 32),
             number_of_outputs=3,
             output_activation="sigmoid",
-            loss="mse"
+            loss="mse",
         )
         self.assertIsInstance(model, models.KerasModel)
 
+        model.predict(np.zeros((1, 64, 64, 1)))
 
     def test_UNet(self):
         model = models.UNet(
@@ -30,10 +44,11 @@ class TestModels(unittest.TestCase):
             steps_per_pooling=1,
             number_of_outputs=1,
             output_activation="sigmoid",
-            loss="mse"
+            loss="mse",
         )
         self.assertIsInstance(model, models.KerasModel)
 
+        model.predict(np.zeros((1, 64, 64, 1)))
 
     def test_RNN(self):
         model = models.rnn(
@@ -44,11 +59,12 @@ class TestModels(unittest.TestCase):
             steps_per_pooling=1,
             number_of_outputs=1,
             output_activation="sigmoid",
-            loss="mse"
+            loss="mse",
         )
         self.assertIsInstance(model, models.KerasModel)
 
+        model.predict(np.zeros((1, 1, 64, 64, 1)))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
\ No newline at end of file
